@@ -1,5 +1,5 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2019-04-05 22:36:56 mtw>
+# Last changed Time-stamp: <2019-08-25 19:14:20 mtw>
 
 # Bio::RNA::RNAaliSplit::WrapAnalyseDists.pm: Wrapper for computing
 # split decompositions
@@ -9,7 +9,7 @@
 
 package Bio::RNA::RNAaliSplit::WrapAnalyseDists;
 
-use version; our $VERSION = qv('0.10');
+use version; our $VERSION = qv('0.11');
 use Carp;
 use Data::Dumper;
 use Moose;
@@ -56,7 +56,6 @@ has 'dim' => (
 	     );
 
 with 'FileDirUtil';
-with 'Bio::RNA::RNAaliSplit::Roles';
 
 sub BUILD {
   my $self = shift;
@@ -66,8 +65,8 @@ sub BUILD {
    $analysedists = can_run('AnalyseDists') or
     croak "ERROR [$this_function] AnalyseDists not found";
   unless($self->has_odir){
-    unless($self->has_dirnam){self->dirnam("as")}
-    $self->odir( [$self->ifile->dir,$self->dirnam] );
+    my $odir_name = "as";
+    $self->odir( [$self->ifile->dir,$odir_name] );
   }
   $oodir = $self->odir->subdir("analysedists");
   my @created = make_path($oodir, {error => \my $err});
@@ -246,4 +245,3 @@ sub _get_dim {
 }
 
 1;
-
