@@ -1,5 +1,5 @@
 #!/usr/bin/env perl
-# Last changed Time-stamp: <2019-04-05 22:54:35 mtw>
+# Last changed Time-stamp: <2019-04-24 01:07:23 mtw>
 # -*-CPerl-*-
 #
 # usage: RNAalisplit.pl -a myfile.aln
@@ -7,7 +7,7 @@
 # NB: Display ID handling in Bio::AlignIO is broken for Stockholm
 # format. Use ClustalW format instead !!!
 
-use version; our $VERSION = qv('0.10');
+use version; our $VERSION = qv('0.11');
 use strict;
 use warnings;
 use Bio::RNA::RNAaliSplit;
@@ -28,7 +28,6 @@ use diagnostics;
 #^^^^^^^^^^ Variables ^^^^^^^^^^^#
 #^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^#
 
-my $format = "ClustalW";
 my $method = "dHn"; # SCI | dHn | dHx | dBp | dBc | dHB
 my $rscape_stat = "GTp";
 my $outdir = "as";
@@ -41,6 +40,7 @@ my $scaleB = 1.;
 my $ribosum = 1;
 my $constraint=undef;
 my $show_version = 0;
+my $do_rscape = 1;
 my %foldme = (); # HoH of folded input sequences for dBp/dBc computation
 
 my %pair = ("AU" => 5,
@@ -54,12 +54,12 @@ my %pair = ("AU" => 5,
 	    "AT" => 5,
 	    "TA" => 6);
 
-
 Getopt::Long::config('no_ignore_case');
 pod2usage(-verbose => 1) unless GetOptions("aln|a=s"      => \$alifile,
 					   "constraint|c=s" => \$constraint,
 					   "method|m=s"   => \$method,
 					   "noribosum"    => sub{$ribosum=0},
+					   "norscape"     => sub{$do_rscape=0},
 					   "out|o=s"      => \$outdir,
 					   "rscapestat=s" => \$rscape_stat,
 					   "scaleH"       => \$scaleH,
@@ -112,10 +112,11 @@ while ($done != 1){
 sub alisplit {
   my ($alnfile,$odirn) = @_;
   my ($what,$alifold,$rscape);
+  my $format = Bio::AlignIO->_guess_format($alnfile);
+  print STDERR "Guess input format $format\n";
   my $AlignSplitObject = Bio::RNA::RNAaliSplit->new(ifile => $alnfile,
 						    format => $format,
-						    odir => $odirn,
-						    dump => 1);
+						    odir => $odirn);
   #print Dumper($AlignSplitObject);
   my $dim = $AlignSplitObject->next_aln->num_sequences;
   my $stkfile = $AlignSplitObject->alignment_stk;
@@ -126,26 +127,38 @@ sub alisplit {
   my $sd = Bio::RNA::RNAaliSplit::WrapAnalyseDists->new(ifile => $dmfile,
 							odir => $AlignSplitObject->odir);
   print STDERR "Identified ".$sd->count." splits\n";
-  print join "\t", ("#hint","RNAz prob","z-score","SCI","seqs","statistic","SSCBP","consensus structure","alignment"), "\n";
+  if ($do_rscape){
+    print join "\t", ("#hint","RNAz prob","z-score","SCI","seqs","statistic","SSCBP","consensus structure","alignment"), "\n";
+  }
+  else {
+    print join "\t", ("#hint","RNAz prob","z-score","SCI","seqs","consensus structure","alignment"), "\n";
+  }
 
   # run RNAalifold for the input alignment
-  $alifold = Bio::RNA::RNAaliSplit::WrapRNAalifold->new(ifile => $alnfile,
+  $alifold = Bio::RNA::RNAaliSplit::WrapRNAalifold->new(ifile => $AlignSplitObject->alignment_aln,
 							odir => $AlignSplitObject->odir,
+							format => 'C',
 							ribosum => $ribosum);
 
   # run RNAz for the input alignment
-  $rnaz = Bio::RNA::RNAaliSplit::WrapRNAz->new(ifile => $alnfile,
+  $rnaz = Bio::RNA::RNAaliSplit::WrapRNAz->new(ifile => $AlignSplitObject->alignment_aln,
 					       odir => $AlignSplitObject->odir);
 
   # run R-scape for the input alignment
-  $rscape = Bio::RNA::RNAaliSplit::WrapRscape->new(ifile => $alifold->alignment_stk, # use RNAalifold-generated stk
-						   odir => $AlignSplitObject->odir,
-						   statistic => $rscape_stat,
-						   nofigures => 1);
-  $rscape->status == 0 ? $what = $rscape->TP : $what = "n/a";
+  if ($do_rscape){
+    $rscape = Bio::RNA::RNAaliSplit::WrapRscape->new(ifile => $alifold->alignment_stk, # use RNAalifold-generated stk
+						     odir => $AlignSplitObject->odir,
+						     statistic => $rscape_stat,
+						     nofigures => 1);
+    $rscape->status == 0 ? $what = $rscape->TP : $what = "n/a";
 
-  print join "\t", "-",$rnaz->P,$rnaz->z,$alifold->sci,$dim,$rscape->statistic,$what,
-    $alifold->consensus_struc,$alnfile."\n";
+    print join "\t", "-",$rnaz->P,$rnaz->z,$alifold->sci,$dim,$rscape->statistic,$what,
+      $alifold->consensus_struc,$alnfile."\n";
+  }
+  else {
+    print join "\t", "-",$rnaz->P,$rnaz->z,$alifold->sci,$dim,
+      $alifold->consensus_struc,$alnfile."\n";
+  }
 
   # extract split sets and run RNAz/RNAalifold/R-scape on each of them
   my $splitnr=1;
@@ -176,22 +189,27 @@ sub evaluate_alignment {
 							 odir => $odir,
 							 ribosum => $ribosum);
   $cs = $alifoldo->consensus_struc;
-  $rscapeo =  Bio::RNA::RNAaliSplit::WrapRscape->new(ifile => $alifoldo->alignment_stk, # use RNAalifold-generated stk
-						     odir => $odir,
-						     statistic => $rscape_stat,
-						     nofigures => 1);
-  if ($rscapeo->status == 0){ # all OK
-    $what = $rscapeo->TP;
-  }
-  elsif ($rscapeo->status == 1){  # no significant basepairs
-    $what = "0:no_sign";
-  }
-  elsif ($rscapeo->status == 2){  # covariation scores are almost constant, no further analysis
-    $what = "0:no_data";
-  }
-  else { $what = "n/a" }
+  if ($do_rscape) {
+    $rscapeo =  Bio::RNA::RNAaliSplit::WrapRscape->new(ifile => $alifoldo->alignment_stk, # use RNAalifold-generated stk
+						       odir => $odir,
+						       statistic => $rscape_stat,
+						       nofigures => 1);
+    if ($rscapeo->status == 0){ # all OK
+      $what = $rscapeo->TP;
+    }
+    elsif ($rscapeo->status == 1){  # no significant basepairs
+      $what = "0:no_sign";
+    }
+    elsif ($rscapeo->status == 2){  # covariation scores are almost constant, no further analysis
+      $what = "0:no_data";
+    }
+    else { $what = "n/a" }
 
-  print join "\t",($hint,$rnazo->P,$rnazo->z,$alifoldo->sci,$count,$rscapeo->statistic,$what,$cs,$aln), "\n";
+    print join "\t",($hint,$rnazo->P,$rnazo->z,$alifoldo->sci,$count,$rscapeo->statistic,$what,$cs,$aln), "\n";
+  }
+  else {
+    print join "\t",($hint,$rnazo->P,$rnazo->z,$alifoldo->sci,$count,$cs,$aln), "\n";
+  }
 }
 
 sub make_distance_matrix {
@@ -232,12 +250,6 @@ sub make_distance_matrix {
     $dHx = $pw_aso->hammingdistX;
     my $id1 = $pw_aso->next_aln->get_seq_by_pos(1)->display_id;
     my $id2 = $pw_aso->next_aln->get_seq_by_pos(2)->display_id;
-   # my $seq1 = $so1->seq;
-   # my $seq2 = $so2->seq;
-   # my ($ss1,$mfe1) = RNA::fold($seq1);
-   # my ($ss2,$mfe2) = RNA::fold($seq2);
-    #print ">> \$seq1: $seq1\n          $ss1\n>> \$seq2: $seq2\n          $ss2\n\n";
- #   print Dumper($so1);
 
     if ($m eq "SCI"){
       # distance = -log( [normalized] pairwise SCI)
@@ -583,6 +595,10 @@ caution. [default: 'dHn']
 Turn off ribosum scoring for RNAalifold computation. Default: ribosum
 scoring on
 
+=item B<--norscape>
+
+Turn off R-scape calculation. Default: R-scape on
+
 =item B<--rscapestat>
 
 R-scape covariation statistic. Allowed values are: 'GT', 'MI', 'MIr',
